@@ -569,8 +569,8 @@ class Samples:
         ran_samp.y_name = self.y_name
         ran_samp.x = self.x[ran_samp_n, :]
         ran_samp.y = self.y[ran_samp_n]
-        ran_samp.nsamp = self.x.shape[0]
-        ran_samp.nfeat = self.x.shape[1]
+        ran_samp.nsamp = ran_samp.x.shape[0]
+        ran_samp.nfeat = ran_samp.x.shape[1]
         ran_samp.index = np.arange(0, ran_samp.nsamp)
 
         if np.issubdtype(ran_samp.x.dtype, np.number):
@@ -592,7 +592,7 @@ class Samples:
         if type(index_list) in (list, tuple, None):
             index_list = np.array(list(set(index_list.copy())))
 
-        if (np.max(index_list) < self.nsamp) or (np.min(index_list) < 0):
+        if (np.max(index_list) > self.nsamp) or (np.min(index_list) < 0):
             raise ValueError("Index list out of bounds with {} min and/or {} max".format(str(np.min(index_list)),
                                                                                          str(np.max(index_list))))
 
@@ -604,8 +604,8 @@ class Samples:
             samp.y_name = self.y_name
             samp.x = self.x[index_list, :]
             samp.y = self.y[index_list]
-            samp.nsamp = self.x.shape[0]
-            samp.nfeat = self.x.shape[1]
+            samp.nsamp = samp.x.shape[0]
+            samp.nfeat = samp.x.shape[1]
             samp.index = np.arange(0, samp.nsamp)
 
             if np.issubdtype(samp.x.dtype, np.number):
